@@ -34,6 +34,8 @@ U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 try:
+  gconf = None
+  gconfClient = None
   import gconf
   gconfClient = gconf.client_get_default()
   useDbus = gconfClient.get_bool("/desktop/gnome/interface/at-spi-dbus")
@@ -49,7 +51,7 @@ if useDbus:
   sys.modules['pyatspi'] = pyatspi_dbus
   del sys
 else:
-  __version__ = (1, 29, 5)
+  __version__ = (1, 29, 6)
 
   REGISTRY_IID = "OAFIID:Accessibility_Registry:1.0"
   TYPELIB_NAME = "Accessibility"
